==> aws-java-sdk-ec2-1.10.30-sources.jar: com/amazonaws/services/ec2/model/ImageAttributeName.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * Image Attribute Name
 */
public enum ImageAttributeName {
    
    Description("description"),
    Kernel("kernel"),
    Ramdisk("ramdisk"),
    LaunchPermission("launchPermission"),
    ProductCodes("productCodes"),
    BlockDeviceMapping("blockDeviceMapping"),
    SriovNetSupport("sriovNetSupport");

    private String value;

    private ImageAttributeName(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return ImageAttributeName corresponding to the value
     */
    public static ImageAttributeName fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("description".equals(value)) {
            return ImageAttributeName.Description;
        } else if ("kernel".equals(value)) {
            return ImageAttributeName.Kernel;
        } else if ("ramdisk".equals(value)) {
            return ImageAttributeName.Ramdisk;
        } else if ("launchPermission".equals(value)) {
            return ImageAttributeName.LaunchPermission;
        } else if ("productCodes".equals(value)) {
            return ImageAttributeName.ProductCodes;
        } else if ("blockDeviceMapping".equals(value)) {
            return ImageAttributeName.BlockDeviceMapping;
        } else if ("sriovNetSupport".equals(value)) {
            return ImageAttributeName.SriovNetSupport;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-java-sdk-ec2-1.11.18-sources.jar: com/amazonaws/services/ec2/model/ImageAttributeName.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model;

/**
 * 
 */
public enum ImageAttributeName {

    Description("description"),
    Kernel("kernel"),
    Ramdisk("ramdisk"),
    LaunchPermission("launchPermission"),
    ProductCodes("productCodes"),
    BlockDeviceMapping("blockDeviceMapping"),
    SriovNetSupport("sriovNetSupport");

    private String value;

    private ImageAttributeName(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return ImageAttributeName corresponding to the value
     */
    public static ImageAttributeName fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        }

        for (ImageAttributeName enumEntry : ImageAttributeName.values()) {
            if (enumEntry.toString().equals(value)) {
                return enumEntry;
            }
        }

        throw new IllegalArgumentException("Cannot create enum from " + value
                + " value!");
    }
}
